# © 2022 Le Filament (<http://www.le-filament.com>)
# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl.html).

import logging

from openupgradelib import openupgrade

_logger = logging.getLogger(__name__)


def update_status_project_accompagnement(env):
    openupgrade.logged_query(
        env.cr,
        """
        UPDATE res_partner rsp
        SET project_status = '4_suivi', membership_status='adhesion'
        WHERE rsp.project_status = '4_adhesion'
        """,
    )


def update_status_project_soumis_cg(env):
    openupgrade.logged_query(
        env.cr,
        """
        UPDATE res_partner rsp
        SET project_status = '4_suivi', membership_status='soumis_cg'
        WHERE rsp.project_status = '5_cg'
        """,
    )


def update_with_new_status(env):
    openupgrade.logged_query(
        env.cr,
        """
        UPDATE res_partner rsp
        SET project_status = (
            CASE
                WHEN rsp.dissolution_date IS NOT NULL THEN '6_decede'
                WHEN rsp.project_status = '6_suivi' THEN '4_suivi'
                WHEN rsp.project_status = '7_abandonne' AND rsp.siret is null THEN '5_abandonne'
                WHEN rsp.project_status = '7_abandonne' AND rsp.siret is not null THEN '4_suivi'
                ELSE project_status
            END
        )
        """,
    )


@openupgrade.migrate()
def migrate(env, version):
    update_status_project_accompagnement(env)
    update_status_project_soumis_cg(env)
    update_with_new_status(env)
